//
//  View.swift
//  Segmented
//
//  Created by Mark Meretzky on 11/23/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class View: UIView {
	let segmentedControl: UISegmentedControl = UISegmentedControl(items: [
		"Record",
		"Stop",
		"Play"
	]);

	let recordingLight: UIView = UIView(frame: CGRectZero);

	//Called from the loadView method of the ViewController.
	
	init(viewController: ViewController) {
		// Initialization code
		super.init(frame: CGRectZero);
		backgroundColor = UIColor.whiteColor();
		segmentedControl.momentary = true;

		//Can't stop until we have started recording or playing.
		segmentedControl.setEnabled(false, forSegmentAtIndex: 1);

		//Can't play until we have recorded something.
		segmentedControl.setEnabled(false, forSegmentAtIndex: 2);

		segmentedControl.addTarget(viewController,
			action: "valueChanged:",
			forControlEvents: UIControlEvents.ValueChanged);

		//Center the segmentedControl in the View.
		segmentedControl.center = center;

		//Keep the segmentedControl at the center of this View,
		//even if the size of this View changes.
		segmentedControl.autoresizingMask =
			UIViewAutoresizing.FlexibleLeftMargin
			| UIViewAutoresizing.FlexibleRightMargin
			| UIViewAutoresizing.FlexibleTopMargin
			| UIViewAutoresizing.FlexibleBottomMargin;

		addSubview(segmentedControl);

		recordingLight.layer.borderWidth = 0.5;	//0.5 pairs of pixels = 1 pixel
		recordingLight.layer.borderColor = UIColor.blueColor().CGColor;
		setRecordingLightTo(false);
		addSubview(recordingLight);
	}

	//Not called.
	required init(coder aDecoder: NSCoder) {
	    super.init(coder: aDecoder);
	}

	override func layoutSubviews() {
		//Length of one side of the square recordingLight.
		let side: CGFloat = segmentedControl.bounds.height / 2;
		let margin: CGFloat = side;	//between recordingLight and segmentedControl

		//Center the recordigLight below the record button of the segmented control.

		recordingLight.frame = CGRectMake(
			center.x - segmentedControl.bounds.width / 3 - side / 2,
			center.y + segmentedControl.bounds.height / 2 + margin,
			side,
			side);
	}

	func setRecordingLightTo(flag: Bool) {
		if flag {
			recordingLight.backgroundColor = UIColor.redColor();	//on
		} else {
			recordingLight.backgroundColor = UIColor.whiteColor();	//off
		}
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect) {
		// Drawing code
	}
	*/

}
