//
//  ViewController.swift
//  Segmented
//
//  Created by Mark Meretzky on 11/23/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit;
import AVFoundation;	//needed for AVAudioSession

class ViewController: UIViewController, AVAudioRecorderDelegate, AVAudioPlayerDelegate {
	let audioSession: AVAudioSession = AVAudioSession.sharedInstance();
	let url: NSURL?;
	let audioRecorder: AVAudioRecorder?;
	var audioPlayer: AVAudioPlayer?;

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);

		//Create an audio session that will silence other applications,
		//except for telephone ringtones and Clock and Calendar alarms.

		if !audioSession.inputAvailable {	//means if audioSession.inputAvailable == false {
			println("device does not support audio input");
			return;
		}

		var error: NSError? = nil;
		if !audioSession.setCategory(AVAudioSessionCategoryPlayAndRecord, error: &error) {
			println("AVAudioSession setCategory: \(error!)");
			return;
		}

		if !audioSession.setActive(true, error: &error) {
			println("AVAudioSession setActive: \(error!)");
			return;
		}

		println("inputNumberOfChannels = \(audioSession.inputNumberOfChannels)");
		println("ouputNumberOfChannels = \(audioSession.outputNumberOfChannels)");
		println("sampleRate = \(audioSession.sampleRate)");
		println("preferredSampleRate = \(audioSession.preferredSampleRate)");
		println("preferredIOBufferDuration = \(audioSession.preferredIOBufferDuration)\n");

		//Create the audio recorder.

		let path: String =
			NSTemporaryDirectory().stringByAppendingPathComponent("recording.caf");
		println("path = \(path)\n");

		url = NSURL(fileURLWithPath: path, isDirectory: false);
		if url == nil {
			println("could not create NSURL");
			return;
		}
		println("url = \(url!)\n");

		let settings: [NSObject: AnyObject] = [
			AVFormatIDKey:         kAudioFormatAppleIMA4,
			AVSampleRateKey:       44100.0,
			AVNumberOfChannelsKey: 2
		];
		audioRecorder = AVAudioRecorder(URL: url!, settings: settings, error: &error);
		if audioRecorder == nil {
			println("could not create AVAudioRecorder: \(error!)");
			return;
		}

		audioRecorder!.delegate = self;
	}

	//Implant a reference to my own self (i.e., the ViewController)
	//into the newborn View.

	override func loadView() {
		view = View(viewController: self);
	}

	override func viewDidLoad() {
		super.viewDidLoad()
		// Do any additional setup after loading the view, typically from a nib.
	}

	func valueChanged(segmentedControl: UISegmentedControl) {
		switch (segmentedControl.selectedSegmentIndex) {

		case 0:	//Record
			if !audioRecorder!.prepareToRecord() {
				println("AVAudioRecorder.prepareToRecord failed.");
			}
			if !audioRecorder!.record() {
				println("AVAudioRecorder.record failed.");
				break;
			}

			(view as View).setRecordingLightTo(true);
			segmentedControl.setEnabled(false, forSegmentAtIndex: 0);	//disable Record
			segmentedControl.setEnabled(true, forSegmentAtIndex: 1);	//enable Stop
			segmentedControl.setEnabled(false, forSegmentAtIndex: 2);	//disable Play
			break;

		case 1:	//Stop
			if audioRecorder!.recording {
				audioRecorder!.stop();
				(view as View).setRecordingLightTo(false);
				segmentedControl.setEnabled(true, forSegmentAtIndex: 0);	//enable Record

				if audioPlayer == nil {
					//Create the audio player.
					var error: NSError? = nil;
					audioPlayer = AVAudioPlayer(contentsOfURL: url!, error: &error);
					if audioPlayer == nil {
						println("could not create AVAudioPlayer: \(error)");
						break;
					}

					audioPlayer!.volume = 1.0;		//the default
					audioPlayer!.numberOfLoops = 0;	//negative for infinite loop
					audioPlayer!.delegate = self;
				} else {
					//Don't let the audio player play any part of the previous recording.
					audioPlayer!.currentTime = 0;
				}
			}

			if audioPlayer!.playing {
				audioPlayer!.stop();
			}

			if !audioPlayer!.prepareToPlay() {
				println("AVAudioPlayer.prepareToPlay failed.");
				break;
			}

			segmentedControl.setEnabled(false, forSegmentAtIndex: 1);	//disable Stop
			segmentedControl.setEnabled(true, forSegmentAtIndex: 2);	//enable Play
			break;

		case 2:	//Play
			if !audioPlayer!.play() {
				println("AVAudioPlayer.play failed.");
				break;
			}

			segmentedControl.setEnabled(true, forSegmentAtIndex: 1);	//enable Stop
			segmentedControl.setEnabled(false, forSegmentAtIndex: 2);	//disable Play
			break;

		default:
			println("segmentedControl.selectedSegmentIndex = \(segmentedControl.selectedSegmentIndex)");
			break;
		}
	}

	func audioRecorderDidFinishRecording(recorder: AVAudioRecorder!, successfully flag: Bool) {
		println("audioRecorderDidFinishRecording:successfully: \(flag)");
	}
	
	func audioRecorderEncodeErrorDidOccur(recorder: AVAudioRecorder!, error: NSError!) {
		(view as View).setRecordingLightTo(false);
		println("audioRecorderEncodeErrorDidOccur:error: \(error)");
	}
	
	func audioPlayerDidFinishPlaying(player: AVAudioPlayer!, successfully flag: Bool) {
		println("audioPlayerDidFinishPlaying:successfully: \(flag)");

		let segmentedControl: UISegmentedControl =
			view.subviews[view.subviews.count - 2] as UISegmentedControl;

		segmentedControl.setEnabled(false, forSegmentAtIndex: 1);	//disable Stop
		segmentedControl.setEnabled(true, forSegmentAtIndex: 2);	//enable Play
	}

	func audioPlayerDecodeErrorDidOccur(player: AVAudioPlayer!, error: NSError!) {
		println("audioPlayerDecodeErrorDidOccur:error: \(error)");
	}

	override func didReceiveMemoryWarning() {
		super.didReceiveMemoryWarning()
		// Dispose of any resources that can be recreated.
	}


}

